@@ -54,7 +54,6 @@
 #' @importFrom qdapTools lookup
 #' @importFrom plotrix color.legend
 #' @importFrom wordcloud wordcloud
-#' @importFrom gdata drop.levels
 #' @examples
 #' \dontrun{
 #' DATA$state <- space_fill(DATA$state, c("is fun", "too fun", "you liar"))
@@ -149,3 +148,9 @@ gradient_cloud <- function(text.var, bigroup.var, rev.binary = FALSE, X = "red",
 }
 
 
+drop.levels <- function(x, reorder=TRUE, ...){
+  x <- x[, drop=TRUE]
+  if(reorder) x <- reorder(x, ...)
+  x
+}
+
