@@ -1,6 +1,7 @@
 #' Remove Stop Words
 #' 
-#' Transcript apply the removal of stop words.
+#' Removal of stop words in a variety of contexts
+#' .
 #' 
 #' @param text.var A character string of text or a vector of character strings.
 #' @param stopwords A character vector of words to remove from the text.  qdap 
@@ -46,8 +47,10 @@
 #' rm_stopwords(DATA$state, Top200Words, unlist = TRUE)
 #' rm_stopwords(DATA$state, Top200Words, unlist = TRUE, strip=TRUE)
 #' rm_stop(DATA$state, Top200Words, unlist = TRUE, unique = TRUE)
+#' 
+#' c("I like it alot", "I like it too") %sw% qdapDictionaries::Top25Words
 #' }
-rm_stopwords<-
+rm_stopwords <-
 function (text.var, stopwords = qdapDictionaries::Top25Words, unlist = FALSE, 
     separate = TRUE, strip = FALSE, unique = FALSE, char.keep = NULL, 
     names = FALSE, ignore.case = TRUE, apostrophe.remove = FALSE, ...) {
@@ -94,3 +97,17 @@ function (text.var, stopwords = qdapDictionaries::Top25Words, unlist = FALSE,
 #' @rdname rm_stopwords
 #' @export
 rm_stop <- rm_stopwords
+
+
+
+#' Remove Stop Words
+#' 
+#' \code{\%sw\%} - Binary operator version of \code{\link[qdap]{rm_stopwords}}  that
+#' defaults to \code{separate = FALSE}..
+#' 
+#' @rdname rm_stopwords
+#' @export
+`%sw%` <- function(text.var, stopwords = qdapDictionaries::Top25Words) {
+    rm_stopwords(text.var = text.var, stopwords = stopwords, separate=FALSE)
+}
+
