@@ -8,7 +8,7 @@ test_that("adjacency_matrix gives desired output",{
     adj <- adjacency_matrix(Terms)
     nms <- c("boolean", "adjacency", "shared", "sum")
     
-    expect_true(identical(nms, names(adj)))
+    expect_equivalent(nms, names(adj))
     expect_true(is.matrix(adj$boolean))
     expect_true(all(dim(adj$boolean) == c(4, 4)))
     expect_false(isSymmetric(adj$boolean))
@@ -16,7 +16,7 @@ test_that("adjacency_matrix gives desired output",{
     expect_true(is.matrix(adj$adjacency))
     expect_true(all(dim(adj$adjacency) == c(4, 4)))
     expect_true(isSymmetric(adj$adjacency))
-    expect_true(identical(diag(adj$adjacency), adj$sum))
+    expect_equivalent(diag(adj$adjacency), adj$sum)
     
     expect_true(is.matrix(adj$shared))
     expect_true(all(dim(adj$shared) == c(3, 3)))
@@ -24,4 +24,3 @@ test_that("adjacency_matrix gives desired output",{
     expect_true(all(sapply(adj$shared[upper.tri(adj$shared)], is.na)))
 	
 })
-
